%global namedreltag  -alpha-3
%global namedversion %{version}%{?namedreltag}
%global dotreltag    %(echo %{namedreltag} | tr - .)

Name:          jspc
Version:       2.0
Release:       %mkrel 0.18%{dotreltag}.3
Summary:       Compile JSPs under Maven
Group:         Development/Java
License:       ASL 2.0
Url:           http://mojo.codehaus.org/jspc/
# svn export https://svn.codehaus.org/mojo/tags/jspc-2.0-alpha-3 jspc
# tar czf jspc-2.0-alpha-3-src-svn.tar.gz jspc
Source0:       %{name}-%{namedversion}-src-svn.tar.gz
Source1:       %{name}-mp-plugin.xml
Patch0:        %{name}-ant-groovyc.patch

BuildRequires: java-devel
BuildRequires: maven-local 

BuildRequires: apache-resource-bundles
BuildRequires: ant
BuildRequires: antlr3-tool
BuildRequires: fusesource-pom
BuildRequires: mvn(commons-lang:commons-lang)
BuildRequires: mvn(org.apache.maven.shared:file-management)
BuildRequires: plexus-containers-container-default
BuildRequires: mvn(org.apache.tomcat:tomcat-servlet-api)
BuildRequires: mvn(org.glassfish.web:javax.servlet.jsp)

BuildRequires: maven-antrun-plugin
BuildRequires: maven-enforcer-plugin
BuildRequires: maven-invoker-plugin
BuildRequires: maven-plugin-plugin
BuildRequires: maven-remote-resources-plugin
BuildRequires: maven-install-plugin

BuildRequires: mvn(org.codehaus.plexus:plexus-component-metadata)

BuildRequires: groovy18
Requires: groovy18

BuildArch:     noarch

%description
The Codehaus is a collaborative environment for building open source
projects with a strong emphasis on modern languages, focused on
quality components that meet real world needs.

Provides support to precompile your JSPs and have them included into
your WAR file. Version 2 of the JSP compilation support includes a
pluggable JSP compiler implementation, which currently allows different
versions of the Tomcat Jasper compiler to be used as needed.

%package javadoc
Group:         Documentation
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}

%pom_remove_parent

for d in LICENSE ; do
  iconv -f iso8859-1 -t utf-8 $d.txt > $d.txt.conv && mv -f $d.txt.conv $d.txt
  sed -i 's/\r//' $d.txt
done

# fix up gmaven removal in src
sed -i 's|import org.codehaus.groovy.maven.mojo.GroovyMojo|import org.apache.maven.plugin.AbstractMojo|' \
  jspc-maven-plugin/src/main/groovy/org/codehaus/mojo/jspc/CompilationMojoSupport.groovy
sed -i 's|extends GroovyMojo|extends AbstractMojo|' \
  jspc-maven-plugin/src/main/groovy/org/codehaus/mojo/jspc/CompilationMojoSupport.groovy

# plexus-maven-plugin superceded by plexus-containers-component-metadata
sed -i 's|<artifactId>plexus-maven-plugin</artifactId>|<artifactId>plexus-component-metadata</artifactId>|' pom.xml

# no tomcat5
%pom_disable_module jspc-compiler-tomcat5 jspc-compilers/pom.xml

# switch tomcat-jasper for glassfish-jsp
%pom_remove_dep org.apache.tomcat:juli jspc-compilers/jspc-compiler-tomcat6/pom.xml
%pom_remove_dep org.apache.tomcat:servlet-api jspc-compilers/jspc-compiler-tomcat6/pom.xml
%pom_remove_dep org.apache.tomcat:jsp-api jspc-compilers/jspc-compiler-tomcat6/pom.xml
%pom_remove_dep org.apache.tomcat:el-api jspc-compilers/jspc-compiler-tomcat6/pom.xml
%pom_remove_dep org.apache.tomcat:jasper-jdt jspc-compilers/jspc-compiler-tomcat6/pom.xml
%pom_remove_dep org.apache.tomcat:annotations-api jspc-compilers/jspc-compiler-tomcat6/pom.xml
%pom_remove_dep org.apache.tomcat:jasper jspc-compilers/jspc-compiler-tomcat6/pom.xml
%pom_remove_dep org.apache.tomcat:jasper-el jspc-compilers/jspc-compiler-tomcat6/pom.xml

# we need servlet 3.0 and jsp 2.2+ in this order
%pom_add_dep org.apache.tomcat:tomcat-servlet-api jspc-compilers/jspc-compiler-tomcat6/pom.xml
%pom_add_dep org.glassfish.web:javax.servlet.jsp jspc-compilers/jspc-compiler-tomcat6/pom.xml

# drop plexus-maven-plugin and add plexus-component-metadata and appropriate config
%pom_remove_plugin org.codehaus.plexus:plexus-maven-plugin jspc-compilers/pom.xml
%pom_add_plugin org.codehaus.plexus:plexus-component-metadata jspc-compilers/pom.xml "
                <configuration>
                  <descriptors>
                    <descriptor>target/classes/META-INF/plexus/components.xml</descriptor>
                  </descriptors>
                </configuration>
                <executions>
                    <execution>
                        <id>create-component-descriptor</id>
                        <phase>generate-resources</phase>
                        <goals>
                            <goal>generate-metadata</goal>
                        </goals>
                    </execution>
                </executions>
"

# fix up source, target config in compiler plugin
%pom_remove_plugin org.apache.maven.plugins:maven-compiler-plugin pom.xml
%pom_add_plugin org.apache.maven.plugins:maven-compiler-plugin pom.xml "
                <configuration>
                    <source>1.7</source>
                    <target>1.7</target>
                </configuration>
"

# fix up source config in javadoc plugin
%pom_remove_plugin org.apache.maven.plugins:maven-javadoc-plugin pom.xml
%pom_add_plugin org.apache.maven.plugins:maven-javadoc-plugin pom.xml "
                <configuration>
                    <source>1.7</source>
                </configuration>
"

# remove wagon-webdav
%pom_xpath_remove "pom:build/pom:extensions"

# get rid of gmaven...
%pom_remove_dep org.codehaus.groovy.maven:gmaven-mojo pom.xml
%pom_remove_plugin org.codehaus.groovy.maven:gmaven-plugin pom.xml
%pom_add_dep org.apache.ant:ant jspc-compilers/jspc-compiler-tomcat6/pom.xml

#...replace with ant groovyc task
# have to patch due to some $ substitution problems
%patch0 -p2

# ant property now needs AntBuilder()
sed -i '/Make directories if needed/a def ant = new AntBuilder()' jspc-maven-plugin/src/main/groovy/org/codehaus/mojo/jspc/CompilationMojoSupport.groovy

%build
%mvn_build

# http://jira.codehaus.org/browse/GMAVEN-68
# gmaven-runtime 1.8 doesn't generate plugin descriptor
# files from javadoc, so we have to load in an existing
# one derived from mvn and g-r 1.6
mkdir -p META-INF/maven/
cp %{SOURCE1} META-INF/maven/plugin.xml
jar uf  %{name}-maven-plugin/target/%{name}-maven-plugin-2.0-alpha-3.jar META-INF/maven/plugin.xml

%install
%mvn_install

%files -f .mfiles
%{_javadir}/%{name}
%doc LICENSE.txt

%files javadoc -f .mfiles-javadoc
%doc LICENSE.txt




%changelog
* Sun May 21 2017 neoclust <neoclust> 2.0-0.18.alpha.3.3.mga6
+ Revision: 1103899
- Fix build
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 2.0-0.18.alpha.3.1.mga6
+ Revision: 977097
- sync package jspc with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Sun Jan 18 2015 daviddavid <daviddavid> 2.0-0.10.alpha.3.4.mga5
+ Revision: 811317
- Sync with fc21

* Wed Oct 15 2014 umeabot <umeabot> 2.0-0.10.alpha.3.3.mga5
+ Revision: 745894
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sat May 24 2014 dmorgan <dmorgan> 2.0-0.10.alpha.3.1.mga5
+ Revision: 625411
- imported package jspc


* Wed Apr 16 2014 Peter MacKinnon <pmackinn@redhat.com> 2.0-0.10.alpha.3
- add AntBuilder to groovy file
- make adjustment for broken tomcat API in 7.0.52

* Fri Mar 28 2014 Michael Simacek <msimacek@redhat.com> - 2.0-0.9.alpha.3
- Use Requires: java-headless rebuild (#1067528)

* Mon Sep 30 2013 Peter MacKinnon <pmackinn@redhat.com> 2.0-0.8.alpha.3
- convert to mvn_build macro for rawhide (#1013615)
- add antlr3-tool BR
- pom duplication fix by removing subpackaging (#1013603)

* Wed Aug 07 2013 Peter MacKinnon <pmackinn@redhat.com> 2.0-0.7.alpha.3
- Replaced gmaven with ant+groovyc
- plexus-containers-container-default update
- mvn-build

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0-0.6.alpha.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jun 11 2013 Peter MacKinnon <pmackinn@redhat.com> 2.0-0.5.alpha.3
- Removed tomcat-lib requires
- TODO: migrate to xmvn beyond F18

* Tue Jun 11 2013 Peter MacKinnon <pmackinn@redhat.com> 2.0-0.4.alpha.3
- Reinstated missing maven-install-plugin

* Thu May 30 2013 Peter MacKinnon <pmackinn@redhat.com> 2.0-0.3.alpha.3
- Updates from peer review

* Tue May 07 2013 Peter MacKinnon <pmackinn@redhat.com> 2.0-0.2.alpha.3
- Re-org sub-package dependencies

* Fri Apr 05 2013 Peter MacKinnon <pmackinn@redhat.com> 2.0-0.1.alpha.3
- Initial rpm
